// TPM Unlock

use crate::{config::DriveConfig, pkg::install_pkgs, run_command};

use super::str_vec;

pub fn setup_tpm_unlock(conf: &DriveConfig) {
    install_pkgs(&["tpm2-tools"]);

    // systemd-cryptenroll --tpm2-device=list

    // Recovery Key
    run_command(
        &str_vec(vec![
            "arch-chroot",
            "/mnt",
            "systemd-cryptenroll",
            "--recovery-key",
            &conf.root,
        ]),
        None,
        false,
    );

    run_command(
        &str_vec(vec![
            "arch-chroot",
            "/mnt",
            "systemd-cryptenroll",
            "--tpm2-device=auto",
            &conf.root,
            "--tpm2-pcrs=7",
        ]),
        None,
        false,
    );
}

// SECURE BOOT

pub fn setup_secure_boot() {
    let (stdout, _) = run_command(&str_vec(vec!["sbctl", "status"]), None, false);
    let binding = stdout.lines().collect::<Vec<&str>>();
    let status = binding.get(1).unwrap();

    if !status.contains("Setup Mode") {
        println!("[!] Secure Boot is not in Setup Mode");
        std::process::exit(1);
    } else {
        if !status.contains("Enabled") {
            println!("[!] Secure Boot is not in Setup Mode");
            std::process::exit(1);
        }
    }

    run_command(&vec!["sbctl".into(), "create-keys".into()], None, false);

    run_command(
        &str_vec(vec!["sbctl", "enroll-keys", "--microsoft"]),
        None,
        false,
    );
    run_command(
        &str_vec(vec![
            "sbctl",
            "sign",
            "-s",
            "/boot/EFI/Linux/arch-linux.efi",
        ]),
        None,
        false,
    );

    run_command(
        &str_vec(vec![
            "sbctl",
            "sign",
            "-s",
            "/boot/EFI/Linux/arch-linux-fallback.efi",
        ]),
        None,
        false,
    );

    run_command(
        &str_vec(vec![
            "sbctl",
            "sign",
            "-s",
            "/boot/EFI/systemd/systemd-bootx64.efi",
        ]),
        None,
        false,
    );

    run_command(
        &str_vec(vec!["sbctl", "sign", "-s", "/boot/EFI/Boot/bootx64.efi"]),
        None,
        false,
    );

    run_command(&str_vec(vec!["sbctl", "verify"]), None, false);
}
